@@ -1,4 +1,5 @@
-import os
+__author__ = 'ardevelop'
+
 import json
 import datetime
 import subprocess
@@ -87,28 +88,9 @@ class Handler(tornado.web.RequestHandler):
         try:
             request = {
                 "headers": self.request.headers,
-                "payload": json.loads(self.request.payload)
+                "payload": json.loads(self.request.body)
             }
         except ValueError:
             raise tornado.web.HTTPError(404)
         else:
-            self.application.queue.append(request)
-
-
-if "__main__" == __name__:
-    import argparse
-
-    parser = argparse.ArgumentParser(prog="githubci",
-                                     description="A simple realization of Continuous Integration for GitHub")
-    parser.add_argument("repository", type=str, help="path to repository")
-    parser.add_argument("-i", "--interface", type=str, help="listen interface", default="127.0.0.1")
-    parser.add_argument("-p", "--port", type=int, help="listen port", default=9092)
-    parser.add_argument("-c", "--config", type=str, help="configuration filename", default="ci.yml")
-
-    args = parser.parse_args()
-
-    os.chdir(args.repository)
-
-    app = Application(config_filename=args.config)
-    app.listen(args.port, args.interface)
-    app.ioloop.start()
\ No newline at end of file
+            self.application.queue.append(request)
\ No newline at end of file
